# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""Update PPRs for CASA6.2.1

Revision ID: b6b319994e85
Revises: b7ef891320a1
Create Date: 2021-10-08 10:25:17.445114

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "b6b319994e85"
down_revision = "b7ef891320a1"
branch_labels = None
depends_on = None


has_ppr = ["std_calibration", "std_cms_imaging", "restore_cma", "std_restore_imaging"]


def upgrade():
    for wf in has_ppr:
        op.execute(
            f"""
            UPDATE workflow_templates
            SET content= regexp_replace(convert_from(content, 'utf-8'), E'hifv_fluxboot2', E'hifv_fluxboot')::bytea
            WHERE filename='PPR.xml' AND workflow_name='{wf}'
            """
        )


def downgrade():
    for wf in has_ppr:
        op.execute(
            f"""
            UPDATE workflow_templates
            SET content= regexp_replace(convert_from(content, 'utf-8'), E'hifv_fluxboot', E'hifv_fluxboot2')::bytea
            WHERE filename='PPR.xml' AND workflow_name='{wf}'
            """
        )
